@@ -1,8 +1,8 @@
-write_lines(
+writeLines(
   "If you see me, something has gone wrong with old-school teardown",
   "DELETE-ME"
 )
-write_lines(
+writeLines(
   "If you see me, something has gone wrong with new-school teardown",
   "DELETE-ME-2"
 )
