@@ -1,4 +1,8 @@
 test_that("captures error before first test", {
+  # Backtrace srcrefs failure
+  skip_on_covr()
+  skip_if_not(is.null(attr(rlang::eval_bare, "srcref")))
+
   local_output_override()
 
   expect_snapshot_reporter(
@@ -43,6 +47,10 @@ test_that("can fully suppress incremental updates", {
 })
 
 test_that("reports backtraces", {
+  # Avoid failures because of different srcrefs in backtraces
+  skip_on_covr()
+  skip_if_not(is.null(attr(rlang::eval_bare, "srcref")))
+
   expect_snapshot_reporter(
     ProgressReporter$new(update_interval = 0, min_time = Inf),
     test_path("reporters/backtraces.R")
@@ -72,8 +80,9 @@ test_that("display of successes only is compact", {
   )
 
   # And even more compact if in RStudio pane
+  local_reproducible_output(rstudio = TRUE)
   expect_snapshot_reporter(
-    CompactProgressReporter$new(rstudio = TRUE),
+    CompactProgressReporter$new(),
     test_path("reporters/successes.R")
   )
 })
