@@ -1,18 +1,16 @@
-context("Basic")
-
 test_that("logical tests act as expected", {
-  expect_that(TRUE, is_true())
-  expect_that(FALSE, is_false())
+  expect_true(TRUE)
+  expect_false(FALSE)
 })
 
 test_that("logical tests ignore attributes", {
-  expect_that(c(a = TRUE), is_true())
-  expect_that(c(a = FALSE), is_false())
+  expect_true(c(a = TRUE))
+  expect_false(c(a = FALSE))
 })
 
 test_that("equality holds", {
-  expect_that(5, equals(5))
-  expect_that(10, is_identical_to(10))
+  expect_equal(5, 5)
+  expect_identical(10, 10)
 })
 
 test_that("can't access variables from other tests 2", {
@@ -20,5 +18,5 @@ test_that("can't access variables from other tests 2", {
 })
 
 test_that("can't access variables from other tests 1", {
-  expect_that(exists("a"), is_false())
+  expect_false(exists("a"))
 })
